pub struct AgentEventLog {
pub sekuire_id: String,
pub session_id: String,
pub workspace_id: Option<String>,
pub event_type: EventType,
pub severity: Severity,
pub event_timestamp: String,
pub event_data: Value,
pub metadata: Value,
}Fields
sekuire_id: Stringsession_id: Stringworkspace_id: Option<String>event_type: EventTypeseverity: Severityevent_timestamp: Stringevent_data: Valuemetadata: ValueTrait Implementations
Sourceimpl Clone for AgentEventLog
impl Clone for AgentEventLog
Sourcefn clone(&self) -> AgentEventLog
fn clone(&self) -> AgentEventLog
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentEventLog
impl Debug for AgentEventLog
Sourceimpl<'de> Deserialize<'de> for AgentEventLog
impl<'de> Deserialize<'de> for AgentEventLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentEventLog
impl JsonSchema for AgentEventLog
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentEventLog
impl RefUnwindSafe for AgentEventLog
impl Send for AgentEventLog
impl Sync for AgentEventLog
impl Unpin for AgentEventLog
impl UnsafeUnpin for AgentEventLog
impl UnwindSafe for AgentEventLog