pub struct AgentEventLogResponse {
pub id: i64,
pub sekuire_id: String,
pub session_id: String,
pub workspace_id: Option<String>,
pub event_type: EventType,
pub severity: Severity,
pub event_timestamp: String,
pub received_at: String,
pub event_data: Value,
pub metadata: Value,
}Fields
id: i64sekuire_id: Stringsession_id: Stringworkspace_id: Option<String>event_type: EventTypeseverity: Severityevent_timestamp: Stringreceived_at: Stringevent_data: Valuemetadata: ValueTrait Implementations
Sourceimpl Clone for AgentEventLogResponse
impl Clone for AgentEventLogResponse
Sourcefn clone(&self) -> AgentEventLogResponse
fn clone(&self) -> AgentEventLogResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentEventLogResponse
impl Debug for AgentEventLogResponse
Sourceimpl<'de> Deserialize<'de> for AgentEventLogResponse
impl<'de> Deserialize<'de> for AgentEventLogResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentEventLogResponse
impl JsonSchema for AgentEventLogResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentEventLogResponse
impl RefUnwindSafe for AgentEventLogResponse
impl Send for AgentEventLogResponse
impl Sync for AgentEventLogResponse
impl Unpin for AgentEventLogResponse
impl UnsafeUnpin for AgentEventLogResponse
impl UnwindSafe for AgentEventLogResponse