pub struct AgentHealthRequest {
pub sekuire_id: String,
pub status: String,
pub session_id: String,
pub sdk_version: String,
pub environment: String,
pub metadata: Value,
}Fields
sekuire_id: Stringstatus: Stringsession_id: Stringsdk_version: Stringenvironment: Stringmetadata: ValueTrait Implementations
Sourceimpl Debug for AgentHealthRequest
impl Debug for AgentHealthRequest
Sourceimpl<'de> Deserialize<'de> for AgentHealthRequest
impl<'de> Deserialize<'de> for AgentHealthRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentHealthRequest
impl JsonSchema for AgentHealthRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentHealthRequest
impl RefUnwindSafe for AgentHealthRequest
impl Send for AgentHealthRequest
impl Sync for AgentHealthRequest
impl Unpin for AgentHealthRequest
impl UnsafeUnpin for AgentHealthRequest
impl UnwindSafe for AgentHealthRequest