pub struct AgentResponse {Show 29 fields
pub sekuire_id: String,
pub public_key: String,
pub name: String,
pub version: String,
pub description: Option<String>,
pub created_at: String,
pub verification_status: VerificationStatus,
pub reputation_score: i32,
pub manifest: Option<Value>,
pub updated_at: Option<String>,
pub publisher_user_id: Option<String>,
pub publisher_email: Option<String>,
pub publisher_name: Option<String>,
pub publisher_org_id: Option<String>,
pub publisher_org_name: Option<String>,
pub org_metadata: Option<Value>,
pub visibility: Option<AgentVisibility>,
pub public_url: Option<String>,
pub git_repository: Option<String>,
pub commit_hash: Option<String>,
pub tag: Option<String>,
pub repository_verified: Option<bool>,
pub readme_content: Option<String>,
pub changelog_content: Option<String>,
pub code_review_status: Option<String>,
pub security_score: Option<i32>,
pub reviewed_by: Option<String>,
pub reviewed_at: Option<String>,
pub review_notes: Option<String>,
}Fields
sekuire_id: Stringpublic_key: Stringname: Stringversion: Stringdescription: Option<String>created_at: Stringverification_status: VerificationStatusreputation_score: i32manifest: Option<Value>updated_at: Option<String>publisher_user_id: Option<String>publisher_email: Option<String>publisher_name: Option<String>publisher_org_id: Option<String>publisher_org_name: Option<String>org_metadata: Option<Value>visibility: Option<AgentVisibility>public_url: Option<String>git_repository: Option<String>commit_hash: Option<String>tag: Option<String>repository_verified: Option<bool>readme_content: Option<String>changelog_content: Option<String>code_review_status: Option<String>security_score: Option<i32>reviewed_by: Option<String>reviewed_at: Option<String>review_notes: Option<String>Trait Implementations
Sourceimpl Debug for AgentResponse
impl Debug for AgentResponse
Sourceimpl<'de> Deserialize<'de> for AgentResponse
impl<'de> Deserialize<'de> for AgentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentResponse
impl JsonSchema for AgentResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentResponse
impl RefUnwindSafe for AgentResponse
impl Send for AgentResponse
impl Sync for AgentResponse
impl Unpin for AgentResponse
impl UnsafeUnpin for AgentResponse
impl UnwindSafe for AgentResponse