pub struct CreateWorkspaceRequest {
pub name: String,
pub policy_preset: String,
}Fields
name: Stringpolicy_preset: StringTrait Implementations
Sourceimpl Debug for CreateWorkspaceRequest
impl Debug for CreateWorkspaceRequest
Sourceimpl<'de> Deserialize<'de> for CreateWorkspaceRequest
impl<'de> Deserialize<'de> for CreateWorkspaceRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateWorkspaceRequest
impl JsonSchema for CreateWorkspaceRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateWorkspaceRequest
impl RefUnwindSafe for CreateWorkspaceRequest
impl Send for CreateWorkspaceRequest
impl Sync for CreateWorkspaceRequest
impl Unpin for CreateWorkspaceRequest
impl UnsafeUnpin for CreateWorkspaceRequest
impl UnwindSafe for CreateWorkspaceRequest