pub struct DelegationTarget {
pub agent_type: String,
pub capabilities: Vec<String>,
}Fields
agent_type: Stringcapabilities: Vec<String>Trait Implementations
Sourceimpl Clone for DelegationTarget
impl Clone for DelegationTarget
Sourcefn clone(&self) -> DelegationTarget
fn clone(&self) -> DelegationTarget
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DelegationTarget
impl Debug for DelegationTarget
Sourceimpl<'de> Deserialize<'de> for DelegationTarget
impl<'de> Deserialize<'de> for DelegationTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DelegationTarget
impl JsonSchema for DelegationTarget
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DelegationTarget
impl RefUnwindSafe for DelegationTarget
impl Send for DelegationTarget
impl Sync for DelegationTarget
impl Unpin for DelegationTarget
impl UnsafeUnpin for DelegationTarget
impl UnwindSafe for DelegationTarget