pub struct DiscoveryMetadata {
pub tags: Vec<String>,
pub categories: Vec<String>,
pub search_keywords: Vec<String>,
}Fields
categories: Vec<String>search_keywords: Vec<String>Trait Implementations
Sourceimpl Clone for DiscoveryMetadata
impl Clone for DiscoveryMetadata
Sourcefn clone(&self) -> DiscoveryMetadata
fn clone(&self) -> DiscoveryMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscoveryMetadata
impl Debug for DiscoveryMetadata
Sourceimpl<'de> Deserialize<'de> for DiscoveryMetadata
impl<'de> Deserialize<'de> for DiscoveryMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiscoveryMetadata
impl JsonSchema for DiscoveryMetadata
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscoveryMetadata
impl RefUnwindSafe for DiscoveryMetadata
impl Send for DiscoveryMetadata
impl Sync for DiscoveryMetadata
impl Unpin for DiscoveryMetadata
impl UnsafeUnpin for DiscoveryMetadata
impl UnwindSafe for DiscoveryMetadata