pub struct DisputeRequest {
pub sekuire_id: String,
pub accuser_id: String,
pub reason: String,
pub evidence_log: String,
}Fields
sekuire_id: Stringaccuser_id: Stringreason: Stringevidence_log: StringTrait Implementations
Sourceimpl Debug for DisputeRequest
impl Debug for DisputeRequest
Sourceimpl<'de> Deserialize<'de> for DisputeRequest
impl<'de> Deserialize<'de> for DisputeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DisputeRequest
impl JsonSchema for DisputeRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DisputeRequest
impl RefUnwindSafe for DisputeRequest
impl Send for DisputeRequest
impl Sync for DisputeRequest
impl Unpin for DisputeRequest
impl UnsafeUnpin for DisputeRequest
impl UnwindSafe for DisputeRequest