pub struct EnhancedReputationResponse {
pub score: i32,
pub rank: Option<i32>,
pub total_agents: i32,
pub task_count: i32,
pub success_count: i32,
pub dispute_count: i32,
pub success_rate: f64,
pub average_rating: f64,
pub verification_badge: Option<String>,
pub recent_logs: Vec<ReputationLog>,
}Fields
score: i32rank: Option<i32>total_agents: i32task_count: i32success_count: i32dispute_count: i32success_rate: f64average_rating: f64verification_badge: Option<String>recent_logs: Vec<ReputationLog>Trait Implementations
Sourceimpl Debug for EnhancedReputationResponse
impl Debug for EnhancedReputationResponse
Sourceimpl<'de> Deserialize<'de> for EnhancedReputationResponse
impl<'de> Deserialize<'de> for EnhancedReputationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EnhancedReputationResponse
impl JsonSchema for EnhancedReputationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EnhancedReputationResponse
impl RefUnwindSafe for EnhancedReputationResponse
impl Send for EnhancedReputationResponse
impl Sync for EnhancedReputationResponse
impl Unpin for EnhancedReputationResponse
impl UnsafeUnpin for EnhancedReputationResponse
impl UnwindSafe for EnhancedReputationResponse