pub struct EnvVarSpec {
pub name: String,
pub required: bool,
pub secret: bool,
pub description: Option<String>,
pub example: Option<String>,
pub default_value: Option<String>,
}Fields
name: Stringrequired: boolsecret: booldescription: Option<String>example: Option<String>default_value: Option<String>Trait Implementations
Sourceimpl Clone for EnvVarSpec
impl Clone for EnvVarSpec
Sourcefn clone(&self) -> EnvVarSpec
fn clone(&self) -> EnvVarSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvVarSpec
impl Debug for EnvVarSpec
Sourceimpl<'de> Deserialize<'de> for EnvVarSpec
impl<'de> Deserialize<'de> for EnvVarSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EnvVarSpec
impl JsonSchema for EnvVarSpec
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EnvVarSpec
impl RefUnwindSafe for EnvVarSpec
impl Send for EnvVarSpec
impl Sync for EnvVarSpec
impl Unpin for EnvVarSpec
impl UnsafeUnpin for EnvVarSpec
impl UnwindSafe for EnvVarSpec