pub struct GetLogsQuery {
pub limit: Option<i64>,
pub offset: Option<i64>,
pub event_type: Option<EventType>,
pub severity: Option<Severity>,
pub session_id: Option<String>,
pub start_time: Option<String>,
pub end_time: Option<String>,
}Fields
limit: Option<i64>offset: Option<i64>event_type: Option<EventType>severity: Option<Severity>session_id: Option<String>start_time: Option<String>end_time: Option<String>Trait Implementations
Sourceimpl Debug for GetLogsQuery
impl Debug for GetLogsQuery
Sourceimpl<'de> Deserialize<'de> for GetLogsQuery
impl<'de> Deserialize<'de> for GetLogsQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetLogsQuery
impl JsonSchema for GetLogsQuery
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetLogsQuery
impl RefUnwindSafe for GetLogsQuery
impl Send for GetLogsQuery
impl Sync for GetLogsQuery
impl Unpin for GetLogsQuery
impl UnsafeUnpin for GetLogsQuery
impl UnwindSafe for GetLogsQuery