pub struct GetLogsResponse {
pub logs: Vec<AgentEventLogResponse>,
pub total: i64,
pub limit: i64,
pub offset: i64,
}Fields
logs: Vec<AgentEventLogResponse>total: i64limit: i64offset: i64Trait Implementations
Sourceimpl Debug for GetLogsResponse
impl Debug for GetLogsResponse
Sourceimpl<'de> Deserialize<'de> for GetLogsResponse
impl<'de> Deserialize<'de> for GetLogsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetLogsResponse
impl JsonSchema for GetLogsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetLogsResponse
impl RefUnwindSafe for GetLogsResponse
impl Send for GetLogsResponse
impl Sync for GetLogsResponse
impl Unpin for GetLogsResponse
impl UnsafeUnpin for GetLogsResponse
impl UnwindSafe for GetLogsResponse