pub struct HandshakeHello {
pub client_nonce: String,
}Fields
client_nonce: StringTrait Implementations
Sourceimpl Debug for HandshakeHello
impl Debug for HandshakeHello
Sourceimpl<'de> Deserialize<'de> for HandshakeHello
impl<'de> Deserialize<'de> for HandshakeHello
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HandshakeHello
impl JsonSchema for HandshakeHello
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HandshakeHello
impl RefUnwindSafe for HandshakeHello
impl Send for HandshakeHello
impl Sync for HandshakeHello
impl Unpin for HandshakeHello
impl UnsafeUnpin for HandshakeHello
impl UnwindSafe for HandshakeHello