pub struct InviteRequest {
pub email: String,
pub role: String,
}Fields
email: Stringrole: StringTrait Implementations
Sourceimpl Debug for InviteRequest
impl Debug for InviteRequest
Sourceimpl<'de> Deserialize<'de> for InviteRequest
impl<'de> Deserialize<'de> for InviteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InviteRequest
impl JsonSchema for InviteRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InviteRequest
impl RefUnwindSafe for InviteRequest
impl Send for InviteRequest
impl Sync for InviteRequest
impl Unpin for InviteRequest
impl UnsafeUnpin for InviteRequest
impl UnwindSafe for InviteRequest