pub struct LeaderboardEntry {
pub rank: i32,
pub sekuire_id: String,
pub name: String,
pub reputation_score: i32,
pub task_count: i32,
pub success_rate: f64,
pub average_rating: f64,
}Fields
rank: i32sekuire_id: Stringname: Stringreputation_score: i32task_count: i32success_rate: f64average_rating: f64Trait Implementations
Sourceimpl Debug for LeaderboardEntry
impl Debug for LeaderboardEntry
Sourceimpl<'de> Deserialize<'de> for LeaderboardEntry
impl<'de> Deserialize<'de> for LeaderboardEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LeaderboardEntry
impl JsonSchema for LeaderboardEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LeaderboardEntry
impl RefUnwindSafe for LeaderboardEntry
impl Send for LeaderboardEntry
impl Sync for LeaderboardEntry
impl Unpin for LeaderboardEntry
impl UnsafeUnpin for LeaderboardEntry
impl UnwindSafe for LeaderboardEntry