pub struct LogEventResponse {
pub success: bool,
pub events_logged: usize,
pub errors: Vec<String>,
}Fields
success: boolevents_logged: usizeerrors: Vec<String>Trait Implementations
Sourceimpl Debug for LogEventResponse
impl Debug for LogEventResponse
Sourceimpl<'de> Deserialize<'de> for LogEventResponse
impl<'de> Deserialize<'de> for LogEventResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LogEventResponse
impl JsonSchema for LogEventResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogEventResponse
impl RefUnwindSafe for LogEventResponse
impl Send for LogEventResponse
impl Sync for LogEventResponse
impl Unpin for LogEventResponse
impl UnsafeUnpin for LogEventResponse
impl UnwindSafe for LogEventResponse