pub struct QuickVerifyResponse {
pub verified: bool,
pub sekuire_id: String,
pub name: String,
pub verification_status: VerificationStatus,
pub reputation_score: i32,
pub badges: Vec<String>,
pub success_rate: Option<f64>,
pub task_count: i32,
pub risk_level: String,
}Fields
verified: boolsekuire_id: Stringname: Stringverification_status: VerificationStatusreputation_score: i32badges: Vec<String>success_rate: Option<f64>task_count: i32risk_level: StringTrait Implementations
Sourceimpl Clone for QuickVerifyResponse
impl Clone for QuickVerifyResponse
Sourcefn clone(&self) -> QuickVerifyResponse
fn clone(&self) -> QuickVerifyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuickVerifyResponse
impl Debug for QuickVerifyResponse
Sourceimpl<'de> Deserialize<'de> for QuickVerifyResponse
impl<'de> Deserialize<'de> for QuickVerifyResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuickVerifyResponse
impl JsonSchema for QuickVerifyResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QuickVerifyResponse
impl RefUnwindSafe for QuickVerifyResponse
impl Send for QuickVerifyResponse
impl Sync for QuickVerifyResponse
impl Unpin for QuickVerifyResponse
impl UnsafeUnpin for QuickVerifyResponse
impl UnwindSafe for QuickVerifyResponse