pub struct ReputationLog {
pub id: String,
pub task_hash: String,
pub rating: i32,
pub comment: Option<String>,
pub timestamp: String,
}Fields
id: Stringtask_hash: Stringrating: i32comment: Option<String>timestamp: StringTrait Implementations
Sourceimpl Debug for ReputationLog
impl Debug for ReputationLog
Sourceimpl<'de> Deserialize<'de> for ReputationLog
impl<'de> Deserialize<'de> for ReputationLog
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReputationLog
impl JsonSchema for ReputationLog
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReputationLog
impl RefUnwindSafe for ReputationLog
impl Send for ReputationLog
impl Sync for ReputationLog
impl Unpin for ReputationLog
impl UnsafeUnpin for ReputationLog
impl UnwindSafe for ReputationLog