pub struct ReputationResponse {
pub score: i32,
pub task_count: i32,
pub verification_badge: Option<String>,
pub recent_logs: Vec<ReputationLog>,
}Fields
score: i32task_count: i32verification_badge: Option<String>recent_logs: Vec<ReputationLog>Trait Implementations
Sourceimpl Debug for ReputationResponse
impl Debug for ReputationResponse
Sourceimpl<'de> Deserialize<'de> for ReputationResponse
impl<'de> Deserialize<'de> for ReputationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReputationResponse
impl JsonSchema for ReputationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReputationResponse
impl RefUnwindSafe for ReputationResponse
impl Send for ReputationResponse
impl Sync for ReputationResponse
impl Unpin for ReputationResponse
impl UnsafeUnpin for ReputationResponse
impl UnwindSafe for ReputationResponse