pub struct TaskCompletionResponse {
pub success: bool,
pub new_reputation_score: i32,
pub reputation_change: i32,
}Fields
success: boolnew_reputation_score: i32reputation_change: i32Trait Implementations
Sourceimpl Debug for TaskCompletionResponse
impl Debug for TaskCompletionResponse
Sourceimpl<'de> Deserialize<'de> for TaskCompletionResponse
impl<'de> Deserialize<'de> for TaskCompletionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TaskCompletionResponse
impl JsonSchema for TaskCompletionResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TaskCompletionResponse
impl RefUnwindSafe for TaskCompletionResponse
impl Send for TaskCompletionResponse
impl Sync for TaskCompletionResponse
impl Unpin for TaskCompletionResponse
impl UnsafeUnpin for TaskCompletionResponse
impl UnwindSafe for TaskCompletionResponse