pub struct UserContextResponse {
pub id: String,
pub email: String,
pub onboarded: bool,
pub mfa_enabled: bool,
pub role: Option<String>,
pub full_name: Option<String>,
pub avatar_url: Option<String>,
pub onboarding_step: i32,
pub profile_completed: bool,
pub orgs: Vec<OrgSummary>,
pub workspaces: Vec<WorkspaceSummary>,
}Fields
id: Stringemail: Stringonboarded: boolmfa_enabled: boolrole: Option<String>full_name: Option<String>avatar_url: Option<String>onboarding_step: i32profile_completed: boolorgs: Vec<OrgSummary>workspaces: Vec<WorkspaceSummary>Trait Implementations
Sourceimpl Clone for UserContextResponse
impl Clone for UserContextResponse
Sourcefn clone(&self) -> UserContextResponse
fn clone(&self) -> UserContextResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserContextResponse
impl Debug for UserContextResponse
Sourceimpl<'de> Deserialize<'de> for UserContextResponse
impl<'de> Deserialize<'de> for UserContextResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserContextResponse
impl JsonSchema for UserContextResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for UserContextResponse
impl RefUnwindSafe for UserContextResponse
impl Send for UserContextResponse
impl Sync for UserContextResponse
impl Unpin for UserContextResponse
impl UnsafeUnpin for UserContextResponse
impl UnwindSafe for UserContextResponse