pub struct VerifyAgentRequest {
pub sekuire_id: String,
pub status: VerificationStatus,
pub badge: Option<String>,
pub reason: Option<String>,
}Fields
sekuire_id: Stringstatus: VerificationStatusbadge: Option<String>reason: Option<String>Trait Implementations
Sourceimpl Debug for VerifyAgentRequest
impl Debug for VerifyAgentRequest
Sourceimpl<'de> Deserialize<'de> for VerifyAgentRequest
impl<'de> Deserialize<'de> for VerifyAgentRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifyAgentRequest
impl JsonSchema for VerifyAgentRequest
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VerifyAgentRequest
impl RefUnwindSafe for VerifyAgentRequest
impl Send for VerifyAgentRequest
impl Sync for VerifyAgentRequest
impl Unpin for VerifyAgentRequest
impl UnsafeUnpin for VerifyAgentRequest
impl UnwindSafe for VerifyAgentRequest