pub struct VerifyAgentResponse {
pub verified: bool,
pub sekuire_id: String,
pub name: String,
pub verification_status: VerificationStatus,
pub reputation_score: i32,
pub badges: Vec<String>,
pub success_rate: Option<f64>,
pub task_count: i32,
pub risk_level: String,
}Fields
verified: boolsekuire_id: Stringname: Stringverification_status: VerificationStatusreputation_score: i32badges: Vec<String>success_rate: Option<f64>task_count: i32risk_level: StringTrait Implementations
Sourceimpl Debug for VerifyAgentResponse
impl Debug for VerifyAgentResponse
Sourceimpl<'de> Deserialize<'de> for VerifyAgentResponse
impl<'de> Deserialize<'de> for VerifyAgentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifyAgentResponse
impl JsonSchema for VerifyAgentResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VerifyAgentResponse
impl RefUnwindSafe for VerifyAgentResponse
impl Send for VerifyAgentResponse
impl Sync for VerifyAgentResponse
impl Unpin for VerifyAgentResponse
impl UnsafeUnpin for VerifyAgentResponse
impl UnwindSafe for VerifyAgentResponse